@@ -94,50 +94,51 @@ def guess_spatial_dimensions(image):
 def convert_colorspace(arr, fromspace, tospace):
     """Convert an image array to a new color space.
 
+    Valid color spaces are:
+        'RGB', 'HSV', 'RGB CIE', 'XYZ', 'YUV', 'YIQ', 'YPbPr', 'YCbCr', 'YDbDr'
+
     Parameters
     ----------
     arr : array_like
         The image to convert.
-    fromspace : str
-        The color space to convert from. Valid color space strings are
-        ``['RGB', 'HSV', 'RGB CIE', 'XYZ', 'YUV', 'YIQ', 'YPbPr', 'YCbCr']``.
-        Value may also be specified as lower case.
-
-    tospace : str
-        The color space to convert to. Valid color space strings are
-        ``['RGB', 'HSV', 'RGB CIE', 'XYZ', 'YUV', 'YIQ', 'YPbPr', 'YCbCr']``.
-        Value may also be specified as lower case.
+    fromspace : valid color space
+        The color space to convert from. Can be specified in lower case.
+    tospace : valid color space
+        The color space to convert to. Can be specified in lower case.
 
     Returns
     -------
-    newarr : ndarray
+    out : ndarray
         The converted image.
 
     Notes
     -----
-    Conversion occurs through the "central" RGB color space, i.e. conversion
-    from XYZ to HSV is implemented as ``XYZ -> RGB -> HSV`` instead of
-    directly.
+    Conversion is performed through the "central" RGB color space,
+    i.e. conversion from XYZ to HSV is implemented as ``XYZ -> RGB -> HSV``
+    instead of directly.
 
     Examples
     --------
     >>> from skimage import data
     >>> img = data.astronaut()
     >>> img_hsv = convert_colorspace(img, 'RGB', 'HSV')
-    """
-    fromdict = {'RGB': lambda im: im, 'HSV': hsv2rgb, 'RGB CIE': rgbcie2rgb,
-                'XYZ': xyz2rgb, 'YUV': yuv2rgb, 'YIQ': yiq2rgb,
-                'YPbPr': ypbpr2rgb, 'YCbCr': ycbcr2rgb}
-    todict = {'RGB': lambda im: im, 'HSV': rgb2hsv, 'RGB CIE': rgb2rgbcie,
-              'XYZ': rgb2xyz, 'YUV': rgb2yuv, 'YIQ': rgb2yiq,
-              'YPbPr': rgb2ypbpr, 'YCbCr': rgb2ycbcr}
 
-    fromspace = fromspace.upper()
-    tospace = tospace.upper()
-    if fromspace not in fromdict.keys():
-        raise ValueError('fromspace needs to be one of %s' % fromdict.keys())
-    if tospace not in todict.keys():
-        raise ValueError('tospace needs to be one of %s' % todict.keys())
+    """
+    fromdict = {'rgb': lambda im: im, 'hsv': hsv2rgb, 'rgb cie': rgbcie2rgb,
+                'xyz': xyz2rgb, 'yuv': yuv2rgb, 'yiq': yiq2rgb,
+                'ypbpr': ypbpr2rgb, 'ycbcr': ycbcr2rgb, 'ydbdr': ydbdr2rgb}
+    todict = {'rgb': lambda im: im, 'hsv': rgb2hsv, 'rgb cie': rgb2rgbcie,
+              'xyz': rgb2xyz, 'yuv': rgb2yuv, 'yiq': rgb2yiq,
+              'ypbpr': rgb2ypbpr, 'ycbcr': rgb2ycbcr, 'ydbdr': rgb2ydbdr}
+
+    fromspace = fromspace.lower()
+    tospace = tospace.lower()
+    if fromspace not in fromdict:
+        msg = '`fromspace` has to be one of {}'.format(fromdict.keys())
+        raise ValueError(msg)
+    if tospace not in todict:
+        msg = '`tospace` has to be one of {}'.format(todict.keys())
+        raise ValueError(msg)
 
     return todict[tospace](fromdict[fromspace](arr))
 
@@ -408,6 +409,13 @@ ycbcr_from_rgb = np.array([[    65.481,   128.553,    24.966],
 
 rgb_from_ycbcr = linalg.inv(ycbcr_from_rgb)
 
+ydbdr_from_rgb = np.array([[    0.299,   0.587,    0.114],
+                           [   -0.45 ,  -0.883,    1.333],
+                           [   -1.333,   1.116,    0.217]])
+
+rgb_from_ydbdr = linalg.inv(ydbdr_from_rgb)
+
+
 # CIE LAB constants for Observer=2A, Illuminant=D65
 # NOTE: this is actually the XYZ values for the illuminant above.
 lab_ref_white = np.array([0.95047, 1., 1.08883])
@@ -811,7 +819,7 @@ def gray2rgb(image, alpha=None):
     Parameters
     ----------
     image : array_like
-        Input image of shape ``(M, N [, P])``.
+        Input image of shape ``(M[, N][, P])``.
     alpha : bool, optional
         Ensure that the output image has an alpha layer.  If None,
         alpha layers are passed through but not created.
@@ -819,13 +827,17 @@ def gray2rgb(image, alpha=None):
     Returns
     -------
     rgb : ndarray
-        RGB image of shape ``(M, N, [, P], 3)``.
+        RGB image of shape ``(M[, N][, P], 3)``.
 
     Raises
     ------
     ValueError
-        If the input is not a 2- or 3-dimensional image.
+        If the input is not a 1-, 2- or 3-dimensional image.
 
+    Notes
+    -----
+    If the input is a 1-dimensional image of shape ``(M, )``, the output
+    will be shape ``(M, 3)``.
     """
     is_rgb = False
     is_alpha = False
@@ -849,7 +861,7 @@ def gray2rgb(image, alpha=None):
 
         return image
 
-    elif image.ndim != 1 and dims in (1, 2, 3):
+    elif dims in (1, 2, 3):
         image = image[..., np.newaxis]
 
         if alpha:
@@ -1691,6 +1703,40 @@ def rgb2ycbcr(rgb):
     return arr
 
 
+def rgb2ydbdr(rgb):
+    """RGB to YDbDr color space conversion.
+
+    Parameters
+    ----------
+    rgb : array_like
+        The image in RGB format, in a 3- or 4-D array of shape
+        ``(M, N, [P,] 3)``.
+
+    Returns
+    -------
+    out : ndarray
+        The image in YDbDr format, in a 3- or 4-D array of shape
+        ``(M, N, [P,] 3)``.
+
+    Raises
+    ------
+    ValueError
+        If `rgb` is not a 3- or 4-D array of shape ``(M, N, [P,] 3)``.
+
+    Notes
+    -----
+    This is the color space which is commonly used
+    by video codecs, it is also the reversible color transform in JPEG2000.
+
+    References
+    ----------
+    .. [1] https://en.wikipedia.org/wiki/YDbDr
+
+    """
+    arr = _convert(ydbdr_from_rgb, rgb)
+    return arr
+
+
 def yuv2rgb(yuv):
     """YUV to RGB color space conversion.
 
@@ -1805,3 +1851,37 @@ def ycbcr2rgb(ycbcr):
     arr[..., 1] -= 128
     arr[..., 2] -= 128
     return _convert(rgb_from_ycbcr, arr)
+
+
+def ydbdr2rgb(ydbdr):
+    """YDbDr to RGB color space conversion.
+
+    Parameters
+    ----------
+    ydbdr : array_like
+        The image in YDbDr format, in a 3- or 4-D array of shape
+        ``(M, N, [P,] 3)``.
+
+    Returns
+    -------
+    out : ndarray
+        The image in RGB format, in a 3- or 4-D array of shape
+        ``(M, N, [P,] 3)``.
+
+    Raises
+    ------
+    ValueError
+        If `ydbdr` is not a 3- or 4-D array of shape ``(M, N, [P,] 3)``.
+
+    Notes
+    -----
+    This is the color space which is commonly used
+    by video codecs, it is also the reversible color transform in JPEG2000.
+
+    References
+    ----------
+    .. [1] https://en.wikipedia.org/wiki/YDbDr
+
+    """
+    arr = ydbdr.copy()
+    return _convert(rgb_from_ydbdr, arr)
