@@ -2,13 +2,11 @@ import itertools
 import math
 import numpy as np
 from scipy import ndimage as ndi
-from scipy.ndimage import filters as ndif
 from collections import OrderedDict
 from ..exposure import histogram
 from .._shared.utils import assert_nD, warn, deprecated
 from ..transform import integral_image
-from .. import util
-from skimage import dtype_limits
+from ..util import crop, dtype_limits
 
 
 __all__ = ['try_all_threshold',
@@ -17,11 +15,13 @@ __all__ = ['try_all_threshold',
            'threshold_yen',
            'threshold_isodata',
            'threshold_li',
+           'threshold_local',
            'threshold_minimum',
            'threshold_mean',
            'threshold_niblack',
            'threshold_sauvola',
-           'threshold_triangle']
+           'threshold_triangle',
+           'apply_hysteresis_threshold']
 
 
 def _try_all(image, methods=None, figsize=None, num_cols=2, verbose=True):
@@ -51,8 +51,7 @@ def _try_all(image, methods=None, figsize=None, num_cols=2, verbose=True):
     num_rows = math.ceil((len(methods) + 1.) / num_cols)
     num_rows = int(num_rows)  # Python 2.7 support
     fig, ax = plt.subplots(num_rows, num_cols, figsize=figsize,
-                           sharex=True, sharey=True,
-                           subplot_kw={'adjustable': 'box-forced'})
+                           sharex=True, sharey=True)
     ax = ax.ravel()
 
     ax[0].imshow(image, cmap=plt.cm.gray)
@@ -354,10 +353,10 @@ def threshold_isodata(image, nbins=256, return_all=False):
     """Return threshold value(s) based on ISODATA method.
 
     Histogram-based threshold, known as Ridler-Calvard method or inter-means.
-    Threshold values returned satisfy the following equality:
+    Threshold values returned satisfy the following equality::
 
-    `threshold = (image[image <= threshold].mean() +`
-                 `image[image > threshold].mean()) / 2.0`
+        threshold = (image[image <= threshold].mean() +
+                     image[image > threshold].mean()) / 2.0
 
     That is, returned thresholds are intensities that separate the image into
     two groups of pixels, where the threshold intensity is midway between the
@@ -601,7 +600,7 @@ def threshold_minimum(image, nbins=256, max_iter=10000):
     smooth_hist = np.copy(hist).astype(np.float64)
 
     for counter in range(max_iter):
-        smooth_hist = ndif.uniform_filter1d(smooth_hist, 3)
+        smooth_hist = ndi.uniform_filter1d(smooth_hist, 3)
         maximum_idxs = find_local_maxima_idx(smooth_hist)
         if len(maximum_idxs) < 3:
             break
@@ -771,10 +770,12 @@ def _mean_std(image, w):
         kern[indices] = (-1) ** (image.ndim % 2 != np.sum(indices) % 2)
 
     sum_full = ndi.correlate(integral, kern, mode='constant')
-    m = util.crop(sum_full, (left_pad, right_pad)) / (w ** image.ndim)
+    m = crop(sum_full, (left_pad, right_pad)) / (w ** image.ndim)
     sum_sq_full = ndi.correlate(integral_sq, kern, mode='constant')
-    g2 = util.crop(sum_sq_full, (left_pad, right_pad)) / (w ** image.ndim)
-    s = np.sqrt(g2 - m * m)
+    g2 = crop(sum_sq_full, (left_pad, right_pad)) / (w ** image.ndim)
+    # Note: we use np.clip because g2 is not guaranteed to be greater than
+    # m*m when floating point error is considered
+    s = np.sqrt(np.clip(g2 - m * m, 0, None))
     return m, s
 
 
@@ -782,9 +783,9 @@ def threshold_niblack(image, window_size=15, k=0.2):
     """Applies Niblack local threshold to an array.
 
     A threshold T is calculated for every pixel in the image using the
-    following formula:
+    following formula::
 
-    T = m(x,y) - k * s(x,y)
+        T = m(x,y) - k * s(x,y)
 
     where m(x,y) and s(x,y) are the mean and standard deviation of
     pixel (x,y) neighborhood defined by a rectangular window with size w
@@ -830,9 +831,9 @@ def threshold_sauvola(image, window_size=15, k=0.2, r=None):
     modification of Niblack technique.
 
     In the original method a threshold T is calculated for every pixel
-    in the image using the following formula:
+    in the image using the following formula::
 
-    T = m(x,y) * (1 + k * ((s(x,y) / R) - 1))
+        T = m(x,y) * (1 + k * ((s(x,y) / R) - 1))
 
     where m(x,y) and s(x,y) are the mean and standard deviation of
     pixel (x,y) neighborhood defined by a rectangular window with size w
@@ -873,11 +874,58 @@ def threshold_sauvola(image, window_size=15, k=0.2, r=None):
     --------
     >>> from skimage import data
     >>> image = data.page()
-    >>> binary_sauvola = threshold_sauvola(image,
-    ...                                    window_size=15, k=0.2)
+    >>> t_sauvola = threshold_sauvola(image, window_size=15, k=0.2)
+    >>> binary_image = image > t_sauvola
     """
     if r is None:
         imin, imax = dtype_limits(image, clip_negative=False)
         r = 0.5 * (imax - imin)
     m, s = _mean_std(image, window_size)
     return m * (1 + k * ((s / r) - 1))
+
+
+def apply_hysteresis_threshold(image, low, high):
+    """Apply hysteresis thresholding to `image`.
+
+    This algorithm finds regions where `image` is greater than `high`
+    OR `image` is greater than `low` *and* that region is connected to
+    a region greater than `high`.
+
+    Parameters
+    ----------
+    image : array, shape (M,[ N, ..., P])
+        Grayscale input image.
+    low : float, or array of same shape as `image`
+        Lower threshold.
+    high : float, or array of same shape as `image`
+        Higher threshold.
+
+    Returns
+    -------
+    thresholded : array of bool, same shape as `image`
+        Array in which `True` indicates the locations where `image`
+        was above the hysteresis threshold.
+
+    Examples
+    --------
+    >>> image = np.array([1, 2, 3, 2, 1, 2, 1, 3, 2])
+    >>> apply_hysteresis_threshold(image, 1.5, 2.5).astype(int)
+    array([0, 1, 1, 1, 0, 0, 0, 1, 1])
+
+    References
+    ----------
+    .. [1] J. Canny. A computational approach to edge detection.
+           IEEE Transactions on Pattern Analysis and Machine Intelligence.
+           1986; vol. 8, pp.679-698.
+           DOI: 10.1109/TPAMI.1986.4767851
+    """
+    low = np.clip(low, a_min=None, a_max=high)  # ensure low always below high
+    mask_low = image > low
+    mask_high = image > high
+    # Connected components of mask_low
+    labels_low, num_labels = ndi.label(mask_low)
+    # Check which connected components contain pixels from mask_high
+    sums = ndi.sum(mask_high, labels_low, np.arange(num_labels + 1))
+    connected_to_high = sums > 0
+    thresholded = connected_to_high[labels_low]
+    return thresholded
