@@ -6,5 +6,7 @@ production code that will depend on updated skimage versions.
 """
 
 from . import graph
+from .manual_segmentation import manual_polygon_segmentation, manual_lasso_segmentation
 
-__all__ = ['graph']
+
+__all__ = ['graph', 'manual_lasso_segmentation', 'manual_polygon_segmentation']
