@@ -5,9 +5,6 @@ from scipy import ndimage as ndi
 from scipy import sparse
 import math
 from ... import measure, segmentation, util, color
-from matplotlib import colors, cm
-from matplotlib import pyplot as plt
-from matplotlib.collections import LineCollection
 
 
 def _edge_generator_from_csr(csr_matrix):
@@ -111,7 +108,7 @@ class RAG(nx.Graph):
 
     """
     The Region Adjacency Graph (RAG) of an image, subclasses
-    `networx.Graph <http://networkx.github.io/documentation/latest/reference/classes.graph.html>`_
+    `networx.Graph <http://networkx.github.io/documentation/latest/reference/classes/graph.html>`_
 
     Parameters
     ----------
@@ -450,7 +447,7 @@ def rag_boundary(labels, edge_map, connectivity=2):
     return rag
 
 
-def show_rag(labels, rag, img, border_color='black', edge_width=1.5,
+def show_rag(labels, rag, image, border_color='black', edge_width=1.5,
              edge_cmap='magma', img_cmap='bone', in_place=True, ax=None):
     """Show a Region Adjacency Graph on an image.
 
@@ -464,7 +461,7 @@ def show_rag(labels, rag, img, border_color='black', edge_width=1.5,
         The labelled image.
     rag : RAG
         The Region Adjacency Graph.
-    img : ndarray, shape (M, N[, 3])
+    image : ndarray, shape (M, N[, 3])
         Input image. If `colormap` is `None`, the image should be in RGB
         format.
     border_color : color spec, optional
@@ -493,29 +490,34 @@ def show_rag(labels, rag, img, border_color='black', edge_width=1.5,
     --------
     >>> from skimage import data, segmentation
     >>> from skimage.future import graph
+    >>> import matplotlib.pyplot as plt
+    >>>
     >>> img = data.coffee()
     >>> labels = segmentation.slic(img)
     >>> g =  graph.rag_mean_color(img, labels)
     >>> lc = graph.show_rag(labels, g, img)
     >>> cbar = plt.colorbar(lc)
     """
+    from matplotlib import colors, cm
+    from matplotlib import pyplot as plt
+    from matplotlib.collections import LineCollection
 
     if not in_place:
         rag = rag.copy()
 
     if ax is None:
         fig, ax = plt.subplots()
-    out = util.img_as_float(img, force_copy=True)
+    out = util.img_as_float(image, force_copy=True)
 
     if img_cmap is None:
-        if img.ndim < 3 or img.shape[2] not in [3, 4]:
+        if image.ndim < 3 or image.shape[2] not in [3, 4]:
             msg = 'If colormap is `None`, an RGB or RGBA image should be given'
             raise ValueError(msg)
         # Ignore the alpha channel
-        out = img[:, :, :3]
+        out = image[:, :, :3]
     else:
         img_cmap = cm.get_cmap(img_cmap)
-        out = color.rgb2gray(img)
+        out = color.rgb2gray(image)
         # Ignore the alpha channel
         out = img_cmap(out)[:, :, :3]
 
