@@ -1,6 +1,8 @@
 # coding: utf-8
 from __future__ import division
 from math import sqrt, atan2, pi as PI
+import itertools
+from warnings import warn
 import numpy as np
 from scipy import ndimage as ndi
 
@@ -9,11 +11,17 @@ from . import _moments
 
 
 from functools import wraps
-from collections import defaultdict
 
 __all__ = ['regionprops', 'perimeter']
 
 
+XY_TO_RC_DEPRECATION_MESSAGE = (
+    'regionprops and image moments (including moments, normalized moments, '
+    'central moments, and inertia tensor) of 2D images will change from xy '
+    'coordinates to rc coordinates in version 0.16.\nSee '
+    'http://scikit-image.org/docs/0.14.x/release_notes_and_installation.html#deprecations '
+    'for details on how to avoid this message.'
+)
 STREL_4 = np.array([[0, 1, 0],
                     [1, 1, 1],
                     [0, 1, 0]], dtype=np.uint8)
@@ -22,6 +30,7 @@ STREL_26_3D = np.ones((3, 3, 3), dtype=np.uint8)
 PROPS = {
     'Area': 'area',
     'BoundingBox': 'bbox',
+    'BoundingBoxArea': 'bbox_area',
     'CentralMoments': 'moments_central',
     'Centroid': 'centroid',
     'ConvexArea': 'convex_area',
@@ -91,11 +100,12 @@ class _RegionProperties(object):
     """
 
     def __init__(self, slice, label, label_image, intensity_image,
-                 cache_active):
+                 cache_active, coordinates):
 
         if intensity_image is not None:
             if not intensity_image.shape == label_image.shape:
-                raise ValueError('Label and intensity image must have the same shape.')
+                raise ValueError('Label and intensity image must have the'
+                                 'same shape.')
 
         self.label = label
 
@@ -106,27 +116,47 @@ class _RegionProperties(object):
         self._cache_active = cache_active
         self._cache = {}
         self._ndim = label_image.ndim
+        # Note: in PR 2603, we added support for nD moments in regionprops.
+        # Many properties used xy coordinates, instead of rc. This attribute
+        # helps with the deprecation process and should be removed in 0.16.
+        if label_image.ndim > 2 or coordinates == 'rc':
+            self._use_xy_warning = False
+            self._transpose_moments = False
+        elif coordinates == 'xy':
+            self._use_xy_warning = False  # don't warn if 'xy' given explicitly
+            self._transpose_moments = True
+        elif coordinates is None:
+            self._use_xy_warning = True
+            self._transpose_moments = True
+        else:
+            raise ValueError('Incorrect value for regionprops coordinates: %s.'
+                             ' Possible values are: "rc", "xy", or None')
 
     @_cached
     def area(self):
         return np.sum(self.image)
 
     def bbox(self):
+        """
+        Returns
+        -------
+        A tuple of the bounding box's start coordinates for each dimension,
+        followed by the end coordinates for each dimension
+        """
         return tuple([self._slice[i].start for i in range(self._ndim)] +
                      [self._slice[i].stop for i in range(self._ndim)])
 
-    def centroid(self):
-        centroid_coords = self.local_centroid
-        return tuple(centroid_coords +
-                     np.array([self._slice[i].start
-                               for i in range(self._ndim)]))
+    def bbox_area(self):
+        return self.image.size
 
-    @only2d
+    def centroid(self):
+        return tuple(self.coords.mean(axis=0))
+
+    @_cached
     def convex_area(self):
         return np.sum(self.convex_image)
 
     @_cached
-    @only2d
     def convex_image(self):
         from ..morphology.convex_hull import convex_hull_image
         return convex_hull_image(self.image)
@@ -149,10 +179,9 @@ class _RegionProperties(object):
         elif self._ndim == 3:
             return (6 * self.area / PI) ** (1. / 3)
 
-    @only2d
     def euler_number(self):
         euler_array = self.filled_image != self.image
-        _, num = label(euler_array, neighbors=8, return_num=True,
+        _, num = label(euler_array, connectivity=self._ndim, return_num=True,
                        background=0)
         return -num + 1
 
@@ -164,7 +193,7 @@ class _RegionProperties(object):
 
     @_cached
     def filled_image(self):
-        structure = STREL_8 if self._ndim == 2 else STREL_26_3D
+        structure = np.ones((3,) * self._ndim)
         return ndi.binary_fill_holes(self.image, structure)
 
     @_cached
@@ -172,22 +201,14 @@ class _RegionProperties(object):
         return self._label_image[self._slice] == self.label
 
     @_cached
-    @only2d
     def inertia_tensor(self):
         mu = self.moments_central
-        a = mu[2, 0] / mu[0, 0]
-        b = -mu[1, 1] / mu[0, 0]
-        c = mu[0, 2] / mu[0, 0]
-        return np.array([[a, b], [b, c]])
+        return _moments.inertia_tensor(self.image, mu)
 
     @_cached
-    @only2d
     def inertia_tensor_eigvals(self):
-        a, b, b, c = self.inertia_tensor.flat
-        # eigen values of inertia tensor
-        l1 = (a + c) / 2 + sqrt(4 * b ** 2 + (a - c) ** 2) / 2
-        l2 = (a + c) / 2 - sqrt(4 * b ** 2 + (a - c) ** 2) / 2
-        return l1, l2
+        return _moments.inertia_tensor_eigvals(self.image,
+                                               T=self.inertia_tensor)
 
     @_cached
     def intensity_image(self):
@@ -198,12 +219,12 @@ class _RegionProperties(object):
     def _intensity_image_double(self):
         return self.intensity_image.astype(np.double)
 
-    @only2d
     def local_centroid(self):
-        m = self.moments
-        row = m[0, 1] / m[0, 0]
-        col = m[1, 0] / m[0, 0]
-        return row, col
+        M = self.moments
+        if self._transpose_moments:
+            M = M.T
+        return tuple(M[tuple(np.eye(self._ndim, dtype=int))] /
+                     M[(0,) * self._ndim])
 
     def max_intensity(self):
         return np.max(self.intensity_image[self.image])
@@ -214,87 +235,84 @@ class _RegionProperties(object):
     def min_intensity(self):
         return np.min(self.intensity_image[self.image])
 
-    @only2d
     def major_axis_length(self):
-        l1, _ = self.inertia_tensor_eigvals
+        l1 = self.inertia_tensor_eigvals[0]
         return 4 * sqrt(l1)
 
-    @only2d
     def minor_axis_length(self):
-        _, l2 = self.inertia_tensor_eigvals
+        l2 = self.inertia_tensor_eigvals[-1]
         return 4 * sqrt(l2)
 
     @_cached
-    @only2d
     def moments(self):
-        return _moments.moments(self.image.astype(np.uint8), 3)
+        M = _moments.moments(self.image.astype(np.uint8), 3)
+        if self._use_xy_warning:
+            warn(XY_TO_RC_DEPRECATION_MESSAGE)
+        if self._transpose_moments:
+            M = M.T
+        return M
 
     @_cached
-    @only2d
     def moments_central(self):
-        row, col = self.local_centroid
-        return _moments.moments_central(self.image.astype(np.uint8),
-                                        row, col, 3)
+        mu = _moments.moments_central(self.image.astype(np.uint8),
+                                      self.local_centroid, order=3)
+        if self._use_xy_warning:
+            warn(XY_TO_RC_DEPRECATION_MESSAGE)
+        if self._transpose_moments:
+            mu = mu.T
+        return mu
 
     @only2d
     def moments_hu(self):
         return _moments.moments_hu(self.moments_normalized)
 
     @_cached
-    @only2d
     def moments_normalized(self):
         return _moments.moments_normalized(self.moments_central, 3)
 
     @only2d
     def orientation(self):
         a, b, b, c = self.inertia_tensor.flat
-        b = -b
         if a - c == 0:
-            if b > 0:
+            if b < 0:
                 return -PI / 4.
             else:
                 return PI / 4.
         else:
-            return - 0.5 * atan2(2 * b, (a - c))
+            return -0.5 * atan2(-2 * b, (a - c))
 
     @only2d
     def perimeter(self):
         return perimeter(self.image, 4)
 
-    @only2d
     def solidity(self):
-        return self.moments[0, 0] / np.sum(self.convex_image)
+        return self.area / self.convex_area
 
-    @only2d
     def weighted_centroid(self):
-        row, col = self.weighted_local_centroid
-        return row + self._slice[0].start, col + self._slice[1].start
+        ctr = self.weighted_local_centroid
+        return tuple(idx + slc.start
+                     for idx, slc in zip(ctr, self._slice))
 
-    @only2d
     def weighted_local_centroid(self):
-        m = self.weighted_moments
-        row = m[0, 1] / m[0, 0]
-        col = m[1, 0] / m[0, 0]
-        return row, col
+        M = self.weighted_moments
+        return (M[tuple(np.eye(self._ndim, dtype=int))] /
+                M[(0,) * self._ndim])
 
     @_cached
-    @only2d
     def weighted_moments(self):
-        return _moments.moments_central(self._intensity_image_double(), 0, 0, 3)
+        return _moments.moments(self._intensity_image_double(), 3)
 
     @_cached
-    @only2d
     def weighted_moments_central(self):
-        row, col = self.weighted_local_centroid
+        ctr = self.weighted_local_centroid
         return _moments.moments_central(self._intensity_image_double(),
-                                        row, col, 3)
+                                        center=ctr, order=3)
 
     @only2d
     def weighted_moments_hu(self):
         return _moments.moments_hu(self.weighted_moments_normalized)
 
     @_cached
-    @only2d
     def weighted_moments_normalized(self):
         return _moments.moments_normalized(self.weighted_moments_central, 3)
 
@@ -339,7 +357,8 @@ class _RegionProperties(object):
         return True
 
 
-def regionprops(label_image, intensity_image=None, cache=True):
+def regionprops(label_image, intensity_image=None, cache=True,
+                coordinates=None):
     """Measure properties of labeled image regions.
 
     Parameters
@@ -353,6 +372,9 @@ def regionprops(label_image, intensity_image=None, cache=True):
         Determine whether to cache calculated properties. The computation is
         much faster for cached properties, whereas the memory consumption
         increases.
+    coordinates : 'rc' or 'xy', optional
+        Coordinate conventions for 2D images. (Only 'rc' coordinates are
+        supported for 3D images.)
 
     Returns
     -------
@@ -367,7 +389,11 @@ def regionprops(label_image, intensity_image=None, cache=True):
     **area** : int
         Number of pixels of region.
     **bbox** : tuple
-        Bounding box ``(min_row, min_col, max_row, max_col)``
+        Bounding box ``(min_row, min_col, max_row, max_col)``.
+        Pixels belonging to the bounding box are in the half-open interval
+        ``[min_row; max_row)`` and ``[min_col; max_col)``.
+    **bbox_area** : int
+        Number of pixels of bounding box.
     **centroid** : array
         Centroid coordinate tuple ``(row, col)``.
     **convex_area** : int
@@ -487,6 +513,10 @@ def regionprops(label_image, intensity_image=None, cache=True):
       for prop in region:
           print(prop, region[prop])
 
+    See Also
+    --------
+    label
+
     References
     ----------
     .. [1] Wilhelm Burger, Mark Burge. Principles of Digital Image Processing:
@@ -520,7 +550,7 @@ def regionprops(label_image, intensity_image=None, cache=True):
         raise TypeError('Only 2-D and 3-D images supported.')
 
     if not np.issubdtype(label_image.dtype, np.integer):
-        raise TypeError('Label image must be of integral type.')
+        raise TypeError('Label image must be of integer type.')
 
     regions = []
 
@@ -532,7 +562,7 @@ def regionprops(label_image, intensity_image=None, cache=True):
         label = i + 1
 
         props = _RegionProperties(sl, label, label_image, intensity_image,
-                                  cache)
+                                  cache, coordinates=coordinates)
         regions.append(props)
 
     return regions
