@@ -1,14 +1,16 @@
 import numpy as np
-from numpy.testing import assert_equal, assert_almost_equal, assert_array_less
-from numpy.testing import assert_raises, assert_array_less
 from skimage.measure import LineModelND, CircleModel, EllipseModel, ransac
 from skimage.transform import AffineTransform
 from skimage.measure.fit import _dynamic_max_trials
-from skimage._shared._warnings import expected_warnings
+
+from skimage._shared import testing
+from skimage._shared.testing import (assert_equal, assert_almost_equal,
+                                     assert_array_less)
 
 
 def test_line_model_invalid_input():
-    assert_raises(ValueError, LineModelND().estimate, np.empty((1, 3)))
+    with testing.raises(ValueError):
+        LineModelND().estimate(np.empty((1, 3)))
 
 
 def test_line_model_predict():
@@ -19,62 +21,50 @@ def test_line_model_predict():
     assert_almost_equal(x, model.predict_x(y))
 
 
-def test_line_model_estimate():
-    # generate original data without noise
-    model0 = LineModelND()
-    model0.params = ((0, 0), (1, 1))
-    x0 = np.arange(-100, 100)
-    y0 = model0.predict_y(x0)
+def test_line_model_nd_invalid_input():
+    with testing.raises(AssertionError):
+        LineModelND().predict_x(np.zeros(1))
 
-    data = np.column_stack([x0, y0])
+    with testing.raises(AssertionError):
+        LineModelND().predict_y(np.zeros(1))
 
-    # estimate parameters of noisy data
-    model_est = LineModelND()
-    model_est.estimate(data)
+    with testing.raises(ValueError):
+        LineModelND().predict_x(np.zeros(1), np.zeros(1))
 
-    # test whether estimated parameters almost equal original parameters
-    random_state = np.random.RandomState(1234)
-    x = random_state.rand(100, 2)
-    assert_almost_equal(model0.predict(x), model_est.predict(x), 1)
+    with testing.raises(AssertionError):
+        LineModelND().predict_y(np.zeros(1))
 
+    with testing.raises(ValueError):
+        LineModelND().predict_y(np.zeros(1), np.zeros(1))
 
-def test_line_model_residuals():
-    model = LineModelND()
-    model.params = (np.array([0, 0]), np.array([0, 1]))
-    assert_equal(model.residuals(np.array([[0, 0]])), 0)
-    assert_equal(model.residuals(np.array([[0, 10]])), 0)
-    assert_equal(model.residuals(np.array([[10, 0]])), 10)
-    model.params = (np.array([-2, 0]), np.array([1, 1])  / np.sqrt(2))
-    assert_equal(model.residuals(np.array([[0, 0]])), np.sqrt(2))
-    assert_almost_equal(model.residuals(np.array([[-4, 0]])), np.sqrt(2))
+    with testing.raises(ValueError):
+        LineModelND().estimate(np.empty((1, 3)))
 
+    with testing.raises(AssertionError):
+        LineModelND().residuals(np.empty((1, 3)))
 
-def test_line_model_under_determined():
     data = np.empty((1, 2))
-    assert_raises(ValueError, LineModelND().estimate, data)
+    with testing.raises(ValueError):
+        LineModelND().estimate(data)
 
 
-def test_line_modelND_invalid_input():
-    assert_raises(ValueError, LineModelND().estimate, np.empty((5, 1)))
-
-
-def test_line_modelND_predict():
+def test_line_model_nd_predict():
     model = LineModelND()
-    model.params = (np.array([0, 0]), np.array([0.2, 0.98]))
+    model.params = (np.array([0, 0]), np.array([0.2, 0.8]))
     x = np.arange(-10, 10)
     y = model.predict_y(x)
     assert_almost_equal(x, model.predict_x(y))
 
 
-def test_line_modelND_estimate():
+def test_line_model_nd_estimate():
     # generate original data without noise
     model0 = LineModelND()
-    model0.params = (np.array([0,0,0], dtype='float'),
-                         np.array([1,1,1], dtype='float')/np.sqrt(3))
+    model0.params = (np.array([0, 0, 0], dtype='float'),
+                     np.array([1, 1, 1], dtype='float')/np.sqrt(3))
     # we scale the unit vector with a factor 10 when generating points on the
     # line in order to compensate for the scale of the random noise
     data0 = (model0.params[0] +
-             10 * np.arange(-100,100)[...,np.newaxis] * model0.params[1])
+             10 * np.arange(-100, 100)[..., np.newaxis] * model0.params[1])
 
     # add gaussian noise to data
     random_state = np.random.RandomState(1234)
@@ -83,6 +73,7 @@ def test_line_modelND_estimate():
     # estimate parameters of noisy data
     model_est = LineModelND()
     model_est.estimate(data)
+    # assert_almost_equal(model_est.residuals(data0), np.zeros(len(data)), 1)
 
     # test whether estimated parameters are correct
     # we use the following geometric property: two aligned vectors have
@@ -97,21 +88,27 @@ def test_line_modelND_estimate():
     assert_almost_equal(np.linalg.norm(np.cross(model0.params[1], a)), 0, 1)
 
 
-def test_line_modelND_residuals():
+def test_line_model_nd_residuals():
     model = LineModelND()
     model.params = (np.array([0, 0, 0]), np.array([0, 0, 1]))
     assert_equal(abs(model.residuals(np.array([[0, 0, 0]]))), 0)
     assert_equal(abs(model.residuals(np.array([[0, 0, 1]]))), 0)
     assert_equal(abs(model.residuals(np.array([[10, 0, 0]]))), 10)
+    # test params argument in model.rediduals
+    data = np.array([[10, 0, 0]])
+    params = (np.array([0, 0, 0]), np.array([2, 0, 0]))
+    assert_equal(abs(model.residuals(data, params=params)), 30)
 
 
 def test_line_modelND_under_determined():
     data = np.empty((1, 3))
-    assert_raises(ValueError, LineModelND().estimate, data)
+    with testing.raises(ValueError):
+        LineModelND().estimate(data)
 
 
 def test_circle_model_invalid_input():
-    assert_raises(ValueError, CircleModel().estimate, np.empty((5, 3)))
+    with testing.raises(ValueError):
+        CircleModel().estimate(np.empty((5, 3)))
 
 
 def test_circle_model_predict():
@@ -140,7 +137,7 @@ def test_circle_model_estimate():
     model_est.estimate(data)
 
     # test whether estimated parameters almost equal original parameters
-    assert_almost_equal(model0.params, model_est.params, 1)
+    assert_almost_equal(model0.params, model_est.params, 0)
 
 
 def test_circle_model_residuals():
@@ -153,7 +150,8 @@ def test_circle_model_residuals():
 
 
 def test_ellipse_model_invalid_input():
-    assert_raises(ValueError, EllipseModel().estimate, np.empty((5, 3)))
+    with testing.raises(ValueError):
+        EllipseModel().estimate(np.empty((5, 3)))
 
 
 def test_ellipse_model_predict():
@@ -256,7 +254,7 @@ def test_ransac_shape():
                                 random_state=1)
 
     # test whether estimated parameters equal original parameters
-    assert_equal(model0.params, model_est.params)
+    assert_almost_equal(model0.params, model_est.params)
     for outlier in outliers:
         assert outlier not in inliers
 
@@ -286,8 +284,8 @@ def test_ransac_geometric():
 
 
 def test_ransac_is_data_valid():
-
-    is_data_valid = lambda data: data.shape[0] > 2
+    def is_data_valid(data):
+        return data.shape[0] > 2
     model, inliers = ransac(np.empty((10, 2)), LineModelND, 2, np.inf,
                             is_data_valid=is_data_valid, random_state=1)
     assert_equal(model, None)
@@ -295,7 +293,6 @@ def test_ransac_is_data_valid():
 
 
 def test_ransac_is_model_valid():
-
     def is_model_valid(model, data):
         return False
     model, inliers = ransac(np.empty((10, 2)), LineModelND, 2, np.inf,
@@ -337,13 +334,12 @@ def test_ransac_dynamic_max_trials():
 
 
 def test_ransac_invalid_input():
-    assert_raises(ValueError, ransac, np.zeros((10, 2)), None, min_samples=2,
-                  residual_threshold=0, max_trials=-1)
-    assert_raises(ValueError, ransac, np.zeros((10, 2)), None, min_samples=2,
-                  residual_threshold=0, stop_probability=-1)
-    assert_raises(ValueError, ransac, np.zeros((10, 2)), None, min_samples=2,
-                  residual_threshold=0, stop_probability=1.01)
-
-
-if __name__ == "__main__":
-    np.testing.run_module_suite()
+    with testing.raises(ValueError):
+        ransac(np.zeros((10, 2)), None, min_samples=2,
+               residual_threshold=0, max_trials=-1)
+    with testing.raises(ValueError):
+        ransac(np.zeros((10, 2)), None, min_samples=2,
+               residual_threshold=0, stop_probability=-1)
+    with testing.raises(ValueError):
+        ransac(np.zeros((10, 2)), None, min_samples=2,
+               residual_threshold=0, stop_probability=1.01)
