@@ -5,14 +5,11 @@
 
 from .deconvolution import wiener, unsupervised_wiener, richardson_lucy
 from .unwrap import unwrap_phase
-from ._denoise import denoise_tv_chambolle, denoise_tv_bregman, \
-                      denoise_bilateral, denoise_wavelet, estimate_sigma
+from ._denoise import (denoise_tv_chambolle, denoise_tv_bregman,
+                       denoise_bilateral, denoise_wavelet, estimate_sigma)
+from ._cycle_spin import cycle_spin
 from .non_local_means import denoise_nl_means
 from .inpaint import inpaint_biharmonic
-from .._shared.utils import copy_func, deprecated
-
-nl_means_denoising = copy_func(denoise_nl_means, name='nl_means_denoising')
-nl_means_denoising = deprecated('skimage.restoration.denoise_nl_means')(nl_means_denoising)
 
 
 __all__ = ['wiener',
@@ -24,7 +21,6 @@ __all__ = ['wiener',
            'denoise_bilateral',
            'denoise_wavelet',
            'denoise_nl_means',
-           'nl_means_denoising',
-           'inpaint_biharmonic']
-
-del copy_func, deprecated
+           'estimate_sigma',
+           'inpaint_biharmonic',
+           'cycle_spin']
