@@ -14,8 +14,8 @@ def configuration(parent_package='', top_path=None):
     cython(['_felzenszwalb_cy.pyx'], working_path=base_path)
     config.add_extension('_felzenszwalb_cy', sources=['_felzenszwalb_cy.c'],
                          include_dirs=[get_numpy_include_dirs()])
-    cython(['_quickshift.pyx'], working_path=base_path)
-    config.add_extension('_quickshift', sources=['_quickshift.c'],
+    cython(['_quickshift_cy.pyx'], working_path=base_path)
+    config.add_extension('_quickshift_cy', sources=['_quickshift_cy.c'],
                          include_dirs=[get_numpy_include_dirs()])
     cython(['_slic.pyx'], working_path=base_path)
     config.add_extension('_slic', sources=['_slic.c'],
@@ -26,7 +26,7 @@ def configuration(parent_package='', top_path=None):
 if __name__ == '__main__':
     from numpy.distutils.core import setup
     setup(maintainer='scikit-image Developers',
-          maintainer_email='scikit-image@googlegroups.com',
+          maintainer_email='scikit-image@python.org',
           description='Segmentation Algorithms',
           url='https://github.com/scikit-image/scikit-image',
           license='SciPy License (BSD Style)',
